@@ -4,6 +4,7 @@ from .wpm import WPM
 from .wsm import WSM
 from .vikor import VIKOR
 from .promethee_ii import PROMETHEE_II
+from .electre_ii import ELECTRE_II
 from .waspas import WASPAS
 
 
@@ -66,8 +67,8 @@ class ENSEMBLE(MCDA):
 
     def __check_mcda_method(self, list_mcda_intances):
         for mcdm in list_mcda_intances:
-            if type(mcdm) not in [TOPSIS, PROMETHEE_II, WASPAS, WSM, WPM, VIKOR]:
-              raise ValueError("list_mcda_intances must be a list of instances of MCDA RANKING methods (TOPSIS, PROMETHEE_II, WASPAS, WSM, WPM, VIKOR)")        
+            if type(mcdm) not in [TOPSIS, PROMETHEE_II, WASPAS, WSM, WPM, VIKOR, ELECTRE_II]:
+              raise ValueError("list_mcda_intances must be a list of instances of MCDA RANKING methods (TOPSIS, PROMETHEE_II, WASPAS, WSM, WPM, VIKOR, ELECTRE_II)")        
         return True
 
     def __verdict(self):
@@ -109,6 +110,7 @@ class ENSEMBLE(MCDA):
         # Get a tie
         a_tie = df_hard.iloc[:,:].agg(lambda x: "a tie" if x.value_counts().values[0] in x.value_counts().values[1:] else x.value_counts().values[0] , axis=1).values.tolist()
 
+        df_hard["std"] = df_hard.iloc[:,:].std(axis=1)
         df_hard["voting"] = df_hard.iloc[:,:].agg(lambda x: x.value_counts().index[0], axis=1)
         df_hard["rank"] = df_hard.iloc[:,:].agg(lambda x: x.value_counts().index[0], axis=1)
 
