@@ -63,11 +63,11 @@ class PROMETHEE_II(MCDA):
 
         df_apf = pd.DataFrame(0, index=np.arange(len(alternatives)), columns=alternatives)
 
-        n_colsrows = self.df_original.shape[1]-1
+        n_colsrows = self.df_original.shape[0]
         x = 0
         for i in range(0, n_colsrows):
             for j in range(0, n_colsrows):            
-                if i != j: 
+                if i != j:
                     df_apf.iloc[i, j] = df_temp.iloc[x, 4]
                     x = x + 1
                     
