@@ -1,4 +1,4 @@
-from mcda import MCDA, pd, np
+from .mcda import MCDA, pd, np
 
 class WASPAS(MCDA):
     def __init__(self):
